@@ -1,12 +1,12 @@
 package Setup::File::TextFragment;
 
-our $DATE = '2015-09-04'; # DATE
-our $VERSION = '0.05'; # VERSION
+our $DATE = '2017-07-10'; # DATE
+our $VERSION = '0.06'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
-use Log::Any::IfLOG '$log';
+use Log::ger;
 
 use File::Trash::Undoable;
 use Text::Fragment;
@@ -124,7 +124,7 @@ sub setup_text_fragment {
     return [412, "$path is not a regular file"] if $is_sym||!$is_file;
 
     open my($fh), "<", $path or return [500, "Can't open $path: $!"];
-    my $text = do { local $/; ~~<$fh> };
+    my $text = do { local $/; scalar <$fh> };
 
     my $res;
     if ($should_exist) {
@@ -146,10 +146,10 @@ sub setup_text_fragment {
 
     if ($tx_action eq 'check_state') {
         if ($should_exist) {
-            $log->info("(DRY) Inserting fragment $id to $path ...")
+            log_info("(DRY) Inserting fragment $id to $path ...")
                 if $dry_run;
         } else {
-            $log->info("(DRY) Deleting fragment $id from $path ...")
+            log_info("(DRY) Deleting fragment $id from $path ...")
                 if $dry_run;
         }
         return [200, "Fragment $id needs to be inserted to $path", undef,
@@ -161,9 +161,9 @@ sub setup_text_fragment {
                 ]}];
     } elsif ($tx_action eq 'fix_state') {
         if ($should_exist) {
-            $log->info("Inserting fragment $id to $path ...");
+            log_info("Inserting fragment $id to $path ...");
         } else {
-            $log->info("Deleting fragment $id from $path ...");
+            log_info("Deleting fragment $id from $path ...");
         }
 
         File::Trash::Undoable::trash(
@@ -193,18 +193,16 @@ Setup::File::TextFragment - Insert/delete text fragment in a file (with undo sup
 
 =head1 VERSION
 
-This document describes version 0.05 of Setup::File::TextFragment (from Perl distribution Setup-File-TextFragment), released on 2015-09-04.
-
-=head1 SEE ALSO
-
-L<Text::Fragment>
-
-L<Setup>
+This document describes version 0.06 of Setup::File::TextFragment (from Perl distribution Setup-File-TextFragment), released on 2017-07-10.
 
 =head1 FUNCTIONS
 
 
-=head2 setup_text_fragment(%args) -> [status, msg, result, meta]
+=head2 setup_text_fragment
+
+Usage:
+
+ setup_text_fragment(%args) -> [status, msg, result, meta]
 
 Insert/delete text fragment in a file (with undo support).
 
@@ -222,6 +220,8 @@ Fixable state: file exists, fragment doesn't exist or payload is not the same
 (if C<should_exist> is true) or fragment still exists (if C<should_exist> is
 false).
 
+This function is not exported by default, but exportable.
+
 This function is idempotent (repeated invocations with same arguments has the same effect as single invocation). This function supports transactions.
 
 
@@ -324,13 +324,19 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<Text::Fragment>
+
+L<Setup>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2017, 2015, 2014, 2013, 2012 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
